@@ -163,7 +163,7 @@ class EdgeFunction(
             retry_attempts=retry_attempts,
         )
 
-        jsii.create(EdgeFunction, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="addAlias")
     def add_alias(
